<?php

    /**

        * @File: tbigrpayment.php

        * @Author: Ilko Ivanov

        * @Author e-mail: ilko.iv@gmail.com

        * @Publisher: Avalon Ltd

        * @Publisher e-mail: home@avalonbg.com

        * @Owner: Avalon Ltd

        * @Version: 1.0.13

	*/

use PrestaShop\PrestaShop\Core\Payment\PaymentOption;	

	

if (!defined('_PS_VERSION_'))

	exit;

if (!defined('TBIGR_LIVEURL'))

	define('TBIGR_LIVEURL', 'https://calc.tbibank.gr');

class TbigrPayment extends PaymentModule {

	public function __construct() {

		$this->name = 'tbigrpayment';

		$this->tab = 'payments_gateways';

		$this->version = '1.0.13';

		$this->author = 'Ilko Ivanov';

		$this->ps_versions_compliancy = array('min' => '1.7.1.0', 'max' => _PS_VERSION_);

        $this->bootstrap = true;

		parent::__construct();

		$this->displayName = $this->l('tbi bank GR Credit Calculator');

		$this->description = $this->l('Calculates the necessary installments and costs for purchasing goods on leasing with tbi bank GR.');

		$this->confirmUninstall = $this->l('Are you sure that you want to uninstall?');

        if (!Configuration::get('TBIGRPAYMENT_NAME'))

			$this->warning = $this->l('No name provided');

	}

	

	public function install() {

        if (Shop::isFeatureActive())

			Shop::setContext(Shop::CONTEXT_ALL);

        if (!(Configuration::get('PS_OS_TBIGRPAYMENT') > 0)){

			$tbigr_name = "tbi bank Payment awaiting validation";

			$tbigr_state_exist = false;

			$tbigr_state_id = 0;

			$tbigr_states = OrderState::getOrderStates((int)$this->context->language->id);

			foreach ($tbigr_states as $state) {

				if (in_array($tbigr_name, $state)) {

					$tbigr_state_exist = true;

					$tbigr_state_id = $state['id_order_state'];

					break;

				}

			}

			if (!$tbigr_state_exist){

				$tbigrpayment_OrderState = new OrderState();

				$tbigrpayment_OrderState->color = "#DDEAF8";

				$tbigrpayment_OrderState->send_mail = 0;

				$tbigrpayment_OrderState->name = $this->name;

				$tbigrpayment_OrderState->template = "";

				$tbigrpayment_OrderState->invoice = 0;

				$tbigrpayment_OrderState->logable = 0;

				$tbigrpayment_OrderState->unremovable = false;

				$tbigrpayment_OrderState->name = array();

				$tbigr_languages = Language::getLanguages(false);

				foreach ($tbigr_languages as $language)

					$tbigrpayment_OrderState->name[$language['id_lang']] = $tbigr_name;        

				$tbigrpayment_OrderState->add();

				Configuration::updateValue('PS_OS_TBIGRPAYMENT',$tbigrpayment_OrderState->id);

			}else{

				Configuration::updateValue('PS_OS_TBIGRPAYMENT',$tbigr_state_id);

			}

		}

        return parent::install() &&

			$this->registerHook('actionFrontControllerSetMedia')&&

            $this->registerHook('displayReassurance')&&

			$this->registerHook('paymentOptions')&&

			$this->registerHook('displayHome')&&

			$this->registerHook('paymentReturn')&&

            Configuration::updateValue('TBIGRPAYMENT_NAME', 'tbi gr pay ro payment');

	}

	

	public function uninstall()	{

        if (!parent::uninstall() ||

			!Configuration::deleteByName('TBIGRPAYMENT_NAME') || 

			!Configuration::deleteByName('PS_OS_TBIGRPAYMENT')

        )

			return false;

        return true;

	}

	

	public function getContent() {

		$output = null;

		if (Tools::isSubmit('submit'.$this->name))

		{

			$credittbigr_status = strval(Tools::getValue('credittbigr_status'));

			$credittbigr_unicid = strval(Tools::getValue('credittbigr_unicid'));

			$credittbigr_store_id = strval(Tools::getValue('credittbigr_store_id'));

			$credittbigr_username = strval(Tools::getValue('credittbigr_username'));

			$credittbigr_password = strval(Tools::getValue('credittbigr_password'));

			$credittbigr_firstlabel = strval(Tools::getValue('credittbigr_firstlabel'));

			$credittbigr_secondlabel = strval(Tools::getValue('credittbigr_secondlabel'));

			$creditirisgr_firstlabel = strval(Tools::getValue('creditirisgr_firstlabel'));

			$creditirisgr_secondlabel = strval(Tools::getValue('creditirisgr_secondlabel'));

			$credittbigr_iris_iban = strval(Tools::getValue('credittbigr_iris_iban'));

			$credittbigr_iris_key = strval(Tools::getValue('credittbigr_iris_key'));

				

			Configuration::updateValue('credittbigr_status', $credittbigr_status);

			Configuration::updateValue('credittbigr_unicid', $credittbigr_unicid);

			Configuration::updateValue('credittbigr_store_id', $credittbigr_store_id);

			Configuration::updateValue('credittbigr_username', $credittbigr_username);

			Configuration::updateValue('credittbigr_password', $credittbigr_password);

			Configuration::updateValue('credittbigr_firstlabel', $credittbigr_firstlabel);

			Configuration::updateValue('credittbigr_secondlabel', $credittbigr_secondlabel);

			Configuration::updateValue('creditirisgr_firstlabel', $creditirisgr_firstlabel);

			Configuration::updateValue('creditirisgr_secondlabel', $creditirisgr_secondlabel);

			Configuration::updateValue('credittbigr_iris_iban', $credittbigr_iris_iban);

			Configuration::updateValue('credittbigr_iris_key', $credittbigr_iris_key);

				

			$output .= $this->displayConfirmation ($this->l('The changes have been successfully saved'));

		}

		return $output.$this->displayForm();

	}

	

	public function displayForm() {

		// Get default language

		$default_lang = (int)Configuration::get('PS_LANG_DEFAULT');

			

		// Init Fields form array

		$fields_form[0]['form'] = array(

			'legend' => array(

			'title' => 'Settings',

		),

		'input' => array(

			array(

				'type'      => 'radio',

				'label'     => 'Display the tbi bank GR button',

				'desc'      => 'Show credit purchase buttons through tbi bank GR',

				'name'      => 'credittbigr_status',

				'required'  => true,

				'class'     => 't',

				'is_bool'   => true,

				'values'    => array(

					array(

						'id'    => 'active_on',

						'value' => 1,

						'label' => 'Yes'

					),

					array(

						'id'    => 'active_off',

						'value' => 0,

						'label' => 'No'

					)

				),

			),

			array(

				'type'      => 'text',

				'label'     => $this->l('Unique shop identifier'),

				'desc'      => $this->l('Unique shop identifier in the tbi bank GR system.'),

				'name'      => 'credittbigr_unicid',

				'size'  => 36,

				'required'  => true

			),

			array(

				'type'      => 'text',

				'label'     => $this->l('Store ID for eCommerce tbi bank GR system'),

				'desc'      => $this->l('Store ID for eCommerce tbi bank GR system. Required for system authentication.'),

				'name'      => 'credittbigr_store_id',

				'size'  => 65,

				'required'  => true

			),

			array(

				'type'      => 'text',

				'label'     => $this->l('Username for eCommerce tbi bank GR system'),

				'desc'      => $this->l('Username for eCommerce tbi bank GR system. Required for system authentication.'),

				'name'      => 'credittbigr_username',

				'size'  => 65,

				'required'  => true

			),

			array(

				'type'      => 'text',

				'label'     => $this->l('Password for eCommerce tbi bank GR system'),

				'desc'      => $this->l('Password for eCommerce tbi bank GR system. Required for system authentication.'),

				'name'      => 'credittbigr_password',

				'size'  => 65,

				'required'  => true

			),

			array(

				'type'      => 'text',

				'label'     => $this->l('First label next to payment button.'),

				'desc'      => $this->l('The first text that appears to the right of the tbi bank GR payment button.'),

				'name'      => 'credittbigr_firstlabel',

				'size'  => 65,

				'required'  => true

			),

			array(

				'type'      => 'text',

				'label'     => $this->l('Second label next to payment button.'),

				'desc'      => $this->l('The second text that appears to the right of the tbi bank GR payment button.'),

				'name'      => 'credittbigr_secondlabel',

				'size'  => 65,

				'required'  => true

			),

			array(

				'type'      => 'text',

				'label'     => $this->l('First label next to IRIS payment button.'),

				'desc'      => $this->l('The first text that appears to the right of the IRIS Pay GR payment button.'),

				'name'      => 'creditirisgr_firstlabel',

				'size'  => 65,

				'required'  => true

			),

			array(

				'type'      => 'text',

				'label'     => $this->l('Second label next to IRIS payment button.'),

				'desc'      => $this->l('The second text that appears to the right of the IRIS Pay GR payment button.'),

				'name'      => 'creditirisgr_secondlabel',

				'size'  => 65,

				'required'  => true

			),

			array(

				'type'      => 'text',

				'label'     => $this->l('IRIS IBAN.'),

				'desc'      => $this->l('IRIS IBAN.'),

				'name'      => 'credittbigr_iris_iban',

				'size'  => 65,

				'required'  => true

			),

			array(

				'type'      => 'text',

				'label'     => $this->l('IRIS Key.'),

				'desc'      => $this->l('IRIS Key.'),

				'name'      => 'credittbigr_iris_key',

				'size'  => 65,

				'required'  => true

			),

		),

			'submit' => array(

				'title' => $this->l('Save'),

				'class' => 'button'

			)

		);

			

		$helper = new HelperForm();

			

		// Module, token and currentIndex

		$helper->module = $this;

		$helper->name_controller = $this->name;

		$helper->token = Tools::getAdminTokenLite('AdminModules');

		$helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name;

			

		// Language

		$helper->default_form_language = $default_lang;

		$helper->allow_employee_form_lang = $default_lang;

			

		// Title and toolbar

		$helper->title = $this->displayName;

		$helper->show_toolbar = true;        // false -> remove toolbar

		$helper->toolbar_scroll = true;      // yes - > Toolbar is always visible on the top of the screen.

		$helper->submit_action = 'submit'.$this->name;

		$helper->toolbar_btn = array(

			'save' => array(

				'desc' => $this->l('Save'),

				'href' => AdminController::$currentIndex.'&configure='.$this->name.'&save'.$this->name.

				'&token='.Tools::getAdminTokenLite('AdminModules'),

			),

			'back' => array(

				'href' => AdminController::$currentIndex.'&token='.Tools::getAdminTokenLite('AdminModules'),

				'desc' => $this->l('Back to list')

			)

		);

			

		// Load current value

		$helper->fields_value['credittbigr_status'] = Configuration::get('credittbigr_status');

		$helper->fields_value['credittbigr_unicid'] = Configuration::get('credittbigr_unicid');

		$helper->fields_value['credittbigr_store_id'] = Configuration::get('credittbigr_store_id');

		$helper->fields_value['credittbigr_username'] = Configuration::get('credittbigr_username');

		$helper->fields_value['credittbigr_password'] = Configuration::get('credittbigr_password');

		$helper->fields_value['credittbigr_firstlabel'] = !empty(Configuration::get('credittbigr_firstlabel')) ? Configuration::get('credittbigr_firstlabel') : $this->l('tbi bank (3-60 installments without card and 100% online)');

		$helper->fields_value['credittbigr_secondlabel'] = !empty(Configuration::get('credittbigr_secondlabel')) ? Configuration::get('credittbigr_secondlabel') : $this->l('Buy now and pay later.');

		$helper->fields_value['creditirisgr_firstlabel'] = Configuration::get('creditirisgr_firstlabel');

		$helper->fields_value['creditirisgr_secondlabel'] = Configuration::get('creditirisgr_secondlabel');

		$helper->fields_value['credittbigr_iris_iban'] = Configuration::get('credittbigr_iris_iban');

		$helper->fields_value['credittbigr_iris_key'] = Configuration::get('credittbigr_iris_key');

			

		return $helper->generateForm($fields_form);

	}

		

	public function checkCurrency($cart) {

		$currency_order = new Currency($cart->id_currency);

		$currencies_module = $this->getCurrency($cart->id_currency);

		if (is_array($currencies_module))

			foreach ($currencies_module as $currency_module)

				if ($currency_order->id == $currency_module['id_currency'])

					return true;

		return false;

	}

	

	public function hookDisplayHome($params) {

			

		$tbigr_unicid = (string)Configuration::get('credittbigr_unicid');

		$tbigr_ch = curl_init();

		curl_setopt($tbigr_ch, CURLOPT_SSL_VERIFYPEER, false);

		curl_setopt($tbigr_ch, CURLOPT_RETURNTRANSFER, true);

		curl_setopt($tbigr_ch, CURLOPT_MAXREDIRS, 2);

		curl_setopt($tbigr_ch, CURLOPT_TIMEOUT, 5);

		curl_setopt($tbigr_ch, CURLOPT_URL, TBIGR_LIVEURL . '/function/getparameters.php?cid='.$tbigr_unicid);

		$paramstbigr=json_decode(curl_exec($tbigr_ch), true);

		curl_close($tbigr_ch);

			

		$tbigr_status = (string)Configuration::get('credittbigr_status');	

		$this->context->smarty->assign(

			array(

				'tbigr_logo' => $this->_path.'css/tbigr_logo.png',

				'tbigr_status_local' => $tbigr_status,

				'tbigr_picture' => TBIGR_LIVEURL . '/calculators/assets/img/tbim' . $paramstbigr['tbi_container_reklama'] . '.png',

				'tbigr_container_status' => $paramstbigr['tbi_container_status'],

				'tbigr_status' => $paramstbigr['tbi_status'],

				'tbigr_container_txt1' => $paramstbigr['tbi_container_txt1'],

				'tbigr_container_txt2' => $paramstbigr['tbi_container_txt2']

			)

		);

			

		return $this->display(__FILE__, 'tbipanel.tpl');

	}

	

	public function hookActionFrontControllerSetMedia($params){

		if ('index' === $this->context->controller->php_self) {

			$this->context->controller->registerStylesheet(

				'tbigrpanel-home-page',

				'modules/'.$this->name.'/css/tbigrpanel.css',

				[

					'media' => 'all',

					'priority' => 200,

				]

			);

		}

	}

		

	public function hookPaymentOptions($params){

		if (!$this->active)

			return;

		if (!$this->checkCurrency($params['cart']))

			return;

		

		$tbigr_unicid = (string)Configuration::get('credittbigr_unicid');

		$tbigr_status = (string)Configuration::get('credittbigr_status');

		

		if ($tbigr_status == 0)

			return;

		

		$tbigr_ch = curl_init();

		curl_setopt($tbigr_ch, CURLOPT_SSL_VERIFYPEER, false);

		curl_setopt($tbigr_ch, CURLOPT_RETURNTRANSFER, true);

		curl_setopt($tbigr_ch, CURLOPT_MAXREDIRS, 2);

		curl_setopt($tbigr_ch, CURLOPT_TIMEOUT, 5);

		curl_setopt($tbigr_ch, CURLOPT_URL, TBIGR_LIVEURL . '/function/getparameters.php?cid='.$tbigr_unicid);

		$paramstbigr=json_decode(curl_exec($tbigr_ch), true);

		curl_close($tbigr_ch);

		

		$tbi_status = $paramstbigr['tbi_status'];

		$iris_status = $paramstbigr['iris_status'];

		

		$cart = $this->context->cart;

		$tbi_price = floatval($cart->getordertotal(true));

		$tbi_minstojnost = floatval($paramstbigr['tbi_minstojnost']);

		$tbi_maxstojnost = floatval($paramstbigr['tbi_maxstojnost']);

		if ($tbi_status == 'Yes' && $tbi_price >= $tbi_minstojnost && $tbi_price <= $tbi_maxstojnost){

			$tbi_status_show = 'Yes';

		}else{

			$tbi_status_show = 'No';

		}

		

		$payment_options = array();

		

		if ($tbi_status_show == 'Yes'){

			$newOption_TBI = new PaymentOption();

			$newOption_TBI->setModuleName($this->name)

				->setCallToActionText((string)Configuration::get('credittbigr_firstlabel'))

				->setAction($this->context->link->getModuleLink(

					$this->name, 

					'validation', 

					array('tbigr_type' => 'TBI'), 

					true

				))

				->setLogo(Media::getMediaPath(_PS_MODULE_DIR_.$this->name.'/css/logo.png'))

				->setAdditionalInformation((string)Configuration::get('credittbigr_secondlabel') . '<br /><br />');

			$payment_options[] = $newOption_TBI;

		}

		

		if ($iris_status == 'Yes'){

			$newOption_IRIS = new PaymentOption();

			$newOption_IRIS->setModuleName($this->name)

				->setCallToActionText((string)Configuration::get('creditirisgr_firstlabel'))

				->setAction($this->context->link->getModuleLink(

					$this->name, 

					'validation', 

					array('tbigr_type' => 'IRIS'), 

					true

				))

				->setLogo(Media::getMediaPath(_PS_MODULE_DIR_.$this->name.'/css/logo.png'))

				->setAdditionalInformation((string)Configuration::get('creditirisgr_secondlabel') . '<br /><br />');

			$payment_options[] = $newOption_IRIS;

		}

		

		return $payment_options;

	}

	

	public function TBIGR_PMT($rate, $nper, $pv, $fv=0, $type = 0) {

		return (-$fv - $pv * pow(1 + $rate, $nper)) / (1 + $rate * $type) / ((pow(1 + $rate, $nper) - 1) / $rate);

	}

		

    public function hookDisplayReassurance($params) {

		if ('product' === $this->context->controller->php_self){

			$tbigr_products = (int)Tools::getValue('id_product');

			$tbigr_product = new Product($tbigr_products);

			$tbigr_status = (string)Configuration::get('credittbigr_status');

			$tbigr_unicid = (string)Configuration::get('credittbigr_unicid');

			

			$tbigr_ch = curl_init();

			curl_setopt($tbigr_ch, CURLOPT_SSL_VERIFYPEER, false);

			curl_setopt($tbigr_ch, CURLOPT_RETURNTRANSFER, true);

			curl_setopt($tbigr_ch, CURLOPT_MAXREDIRS, 2);

			curl_setopt($tbigr_ch, CURLOPT_TIMEOUT, 5);

			curl_setopt($tbigr_ch, CURLOPT_URL, TBIGR_LIVEURL . '/function/getparameters.php?cid='.$tbigr_unicid);

			$paramstbigr = json_decode(curl_exec($tbigr_ch), true);

			

			curl_close($tbigr_ch);

			$tbi_btn_color = '#e55a00;';

			if ($paramstbigr['tbi_btn_theme'] == 'tbi'){

				$tbi_btn_color = '#e55a00;';

			}

			if ($paramstbigr['tbi_btn_theme'] == 'tbi2'){

				$tbi_btn_color = '#00368a;';

			}

			if ($paramstbigr['tbi_btn_theme'] == 'tbi3'){

				$tbi_btn_color = '#2b7953;';

			}

			if ($paramstbigr['tbi_btn_theme'] == 'tbi4'){

				$tbi_btn_color = '#848789;';

			}

			

			$tbi_divider = floatval($paramstbigr['tbi_divider']);

			if ($tbigr_product->getPrice() < $tbi_divider){

				$tbi_rate = floatval($paramstbigr['tbi_rate']);

				$tbi_commission = floatval($paramstbigr['tbi_commission']);

				$tbi_insurance = floatval($paramstbigr['tbi_insurance']);

				$tbi_months = intval($paramstbigr['tbi_months']);			

			}else{

				$tbi_rate = floatval($paramstbigr['tbi_rate2']);

				$tbi_commission = floatval($paramstbigr['tbi_commission2']);

				$tbi_insurance = floatval($paramstbigr['tbi_insurance2']);

				$tbi_months = intval($paramstbigr['tbi_months2']);			

			}

			

			if ($tbi_rate == 0){

				$tbi_rate = 1;

			}

			

			$tbigr_mesecna = $this->TBIGR_PMT(($tbi_rate / 100) / 12, $tbi_months,  - ($tbigr_product->getPrice() + $tbi_commission) * (1 + $tbi_insurance * $tbi_months));

			if ($paramstbigr['tbi_backurl'] != ''){

				if (preg_match("#https?://#", $paramstbigr['tbi_backurl']) === 0) {

					$tbi_backurl = 'http://'.$paramstbigr['tbi_backurl'];

				}else{

					$tbi_backurl = $paramstbigr['tbi_backurl'];

				}

			}else{

				$tbi_backurl = '';

			}

			

			$this->context->smarty->assign(

				array(

					'unicid' => $tbigr_unicid,

					'tbigr_btn_theme' => $paramstbigr['tbi_btn_theme'],

					'tbigr_custom_button_status' => $paramstbigr['tbi_custom_button_status'],

					'tbigr_zaglavie' => $paramstbigr['tbi_zaglavie'],

					'tbigr_opisanie' => $paramstbigr['tbi_opisanie'],

					'tbigr_product' => $paramstbigr['tbi_product'],

					'tbigr_mod_version' => $this->version,

					'tbigr_backurl' => $tbi_backurl,

					'tbigr_vnoska' => $paramstbigr['tbi_vnoska'],

					'tbi_btn_color' => $tbi_btn_color,

					'tbigr_mesecna' => number_format($tbigr_mesecna, 2, '.', ''),

					'tbi_months' => $tbi_months,

					'tbigr_liveurl' => TBIGR_LIVEURL,

					'tbigr_btnvisible' => $paramstbigr['tbi_btnvisible'],

					'tbigr_status_local' => $tbigr_status

				)

			);

		}

		

		if ($this->context->controller->php_self == 'product'){

			if ($paramstbigr['tbi_status'] == 'Yes' && ($tbigr_product->getPrice() >= $paramstbigr['tbi_minstojnost']) && ($tbigr_product->getPrice() <= $paramstbigr['tbi_maxstojnost'])){

				return $this->display(__FILE__, 'tbigrpayment.tpl');

			}else{

				return null;

			}

		}else{

			return null;

		}

	}

	

	public function hookPaymentReturn($params){

		$tbigr_url = '';

		

		if (!$this->active)

			return;

		

		$state = $params['order']->getCurrentState();

		if (in_array($state, array(Configuration::get('PS_OS_TBIGRPAYMENT'), Configuration::get('PS_OS_OUTOFSTOCK'), Configuration::get('PS_OS_OUTOFSTOCK_UNPAID')))){

			$tbigr_encrypt = Tools::getValue('enc');

			$tbigr_envurl = Tools::getValue('envurl');

			$tbi_pause_txt = Tools::getValue('tbi_pause_txt');

			$tbigr_type = Tools::getValue('tbigr_type');

			$tbigr_env = Tools::getValue('tbigr_env');

			$tbigr_ocp = '';

			if ($tbigr_env == 'tbi_test'){

				$tbigr_ocp = '1f0a04a6ad7a4dac80c664706fdcb93c';

			}

			if ($tbigr_env == 'tbi_live'){

				$tbigr_ocp = 'd2304c1fe5de43d8837d081192a9a39b';

			}

			

			$cookie = new Cookie('tbigrpayment_cookie');

			$send_tbigr = $cookie->send_tbigr;

			

			if (($tbigr_encrypt != '') && ($send_tbigr == 'No')){

				$cookie->send_tbigr = 'Yes';

				$tbigr_plaintext = base64_decode($tbigr_encrypt);

				

				if ($tbigr_envurl != ''){

					$tbigr_unicid = (string)Configuration::get('credittbigr_unicid');

					$tbigr_username = (string)Configuration::get('credittbigr_username');

					$tbigr_password = (string)Configuration::get('credittbigr_password');

					$tbigr_iris_key = (string)Configuration::get('credittbigr_iris_key');

					

					if ($tbigr_type == 'TBI'){

						$curl_token = curl_init();

						curl_setopt_array($curl_token, array(

							CURLOPT_URL 			=> $tbigr_envurl . '/User/authorize',

							CURLOPT_RETURNTRANSFER 	=> true,

							CURLOPT_ENCODING 		=> '',

							CURLOPT_MAXREDIRS 		=> 4,

							CURLOPT_TIMEOUT 		=> 0,

							CURLOPT_FOLLOWLOCATION 	=> true,

							CURLOPT_HTTP_VERSION 	=> CURL_HTTP_VERSION_1_1,

							CURLOPT_CUSTOMREQUEST 	=> 'POST',

							CURLOPT_POSTFIELDS 		=>'{"username":"' . $tbigr_username . '","password":"' . $tbigr_password . '"}',

							CURLOPT_HTTPHEADER 		=> array(

								'Content-Type: application/json',

								'Ocp-Apim-Subscription-Key: ' . $tbigr_ocp,

								'Ocp-Apim-Trace: true'

							),

						));

						$response_token = curl_exec($curl_token);

						curl_close($curl_token);

						

						$tbigr_token = json_decode($response_token);

					

						if (!empty($tbigr_token->token)){

							$curl_application = curl_init();

							curl_setopt_array($curl_application, array(

								CURLOPT_URL => $tbigr_envurl . '/Application',

								CURLOPT_RETURNTRANSFER => true,

								CURLOPT_ENCODING => '',

								CURLOPT_MAXREDIRS => 4,

								CURLOPT_TIMEOUT => 0,

								CURLOPT_FOLLOWLOCATION => true,

								CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,

								CURLOPT_CUSTOMREQUEST => 'POST',

								CURLOPT_POSTFIELDS => $tbigr_plaintext,

								CURLOPT_HTTPHEADER => array(

									'Content-Type: application/json',

									'Ocp-Apim-Subscription-Key: ' . $tbigr_ocp,

									'Ocp-Apim-Trace: true',

									'AuthorizationToken: ' . $tbigr_token->token

								),

							));

							$response_application = curl_exec($curl_application);

							curl_close($curl_application);

							$tbigr_result = json_decode($response_application);

							

							if ($tbigr_result->ErrorCode == null){

								$tbigr_url = $tbigr_result->Url;

								//var_dump($tbigr_plaintext);

								//var_dump($tbigr_result);

								//die;

							}

						}

					}

					

					if ($tbigr_type == 'IRIS'){

						$curl_application = curl_init();

							curl_setopt_array($curl_application, array(

							CURLOPT_URL => $tbigr_envurl . '/' . $tbigr_iris_key,

							CURLOPT_RETURNTRANSFER => true,

							CURLOPT_ENCODING => '',

							CURLOPT_MAXREDIRS => 4,

							CURLOPT_TIMEOUT => 0,

							CURLOPT_FOLLOWLOCATION => true,

							CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,

							CURLOPT_CUSTOMREQUEST => 'POST',

							CURLOPT_POSTFIELDS => $tbigr_plaintext,

							CURLOPT_HTTPHEADER => array(

								'Content-Type: application/json'

							),

						));

						$response_application = curl_exec($curl_application);

						curl_close($curl_application);

						$tbigriris_result = json_decode($response_application);

						if ($tbigriris_result->paymentLink != null){

							$tbigr_url = $tbigriris_result->paymentLink;

							//var_dump($tbigriris_plaintext);

							//var_dump($tbigriris_result);

							//die;

						}

					}

				}

			}else{

				die('Communication problem or You have already sent this order!');

			}

			

			$tbigr_total_to_pay = Tools::displayPrice($params['order']->getOrdersTotalPaid(), new Currency($params['order']->id_currency), false);

			

			$this->smarty->assign(array(

				'tbigr_total_to_pay' => $tbigr_total_to_pay,

				'tbigr_status' => 'ok',

				'tbi_pause_txt' => $tbi_pause_txt,

				'tbigrlogo' => __PS_BASE_URI__ . 'modules/tbigrpayment/css/logo.png',

				'tbigr_url' => $tbigr_url

			));

		}else{

			$this->smarty->assign('status', 'failed');

		}

		return $this->display(__FILE__, 'payment_return.tpl');

	}

	

}